API
===

.. module:: pygindex.client


Client
------

User Authentication Data Object
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: IGUserAuth
   :members:
   :inherited-members:

IG API Configuration Data Object
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: IGAPIConfig
   :members:
   :inherited-members:

Session Data Object
~~~~~~~~~~~~~~~~~~~

.. autoclass:: IGSession
   :members:
   :inherited-members:

Response Data Object
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: IGResponse
   :members:
   :inherited-members:

Client Object
~~~~~~~~~~~~~

.. autoclass:: IGClient
   :members:
   :inherited-members:
